Crate typedb_driver

Crate typedb_driver 

Re-exports

pub use self::driver::TypeDBDriver;
pub use self::transaction::Transaction;

Modules

analyze
answer
concept
driver
error
given
info
transaction

Macros

promisify
resolve

Structs

Address
AvailableServer
A specialization of an available Server with a known connection address.
Credentials
User credentials for connecting to TypeDB
Database
A TypeDB database.
DatabaseManager
Provides access to all database management methods.
DriverOptions
TypeDB driver connection options. DriverOptions object can be used to override the default driver behavior while connecting to TypeDB.
DriverTlsConfig
TLS configuration for the TypeDB driver.
QueryOptions
TypeDB query options. QueryOptions object can be used to override the default server behaviour for executed queries.
ServerVersion
A full TypeDB server’s version specification
TransactionOptions
TypeDB transaction options. TransactionOptions object can be used to override the default behaviour for opened transactions.
User
A TypeDB server user, identified by a username.
UserManager
Provides access to all user management methods.

Enums

Addresses
A collection of server addresses used for connection.
Error
Represents errors encountered during operation.
ReplicationRole
This enum is used to specify the replication role of a server.
Server
The metadata and state of an individual server of a driver connection.
ServerRouting
Server routing directive for operations against a distributed server. All driver methods have default recommended values, however, some operations can be configured in order to target a specific server in the cluster. This setting does not affect clusters with a single node.
TransactionType
This enum is used to specify the type of transaction.

Traits

Promise
Async promise, an alias for Rust’s built-in Future. A BoxPromise is an alias for Rust’s built-in BoxFuture.
Replica

Functions

box_stream

Type Aliases

BoxPromise
An owned dynamically typed Future for use in cases where you can’t statically type your result or need to add some indirection.
BoxStream
An owned dynamically typed Stream for use in cases where you can’t statically type your result or need to add some indirection.
IID
Result