pub enum Concept {
RootThingType(RootThingType),
EntityType(EntityType),
RelationType(RelationType),
RoleType(RoleType),
AttributeType(AttributeType),
Entity(Entity),
Relation(Relation),
Attribute(Attribute),
Value(Value),
}Expand description
The fundamental TypeQL object. A Concept is either a Type, Thing, or Value. To use subtype specific methods, the Concept must be of the expected subtype.
Variants
RootThingType(RootThingType)
EntityType(EntityType)
RelationType(RelationType)
RoleType(RoleType)
AttributeType(AttributeType)
Entity(Entity)
Relation(Relation)
Attribute(Attribute)
Value(Value)