Attribute

Struct Attribute 

pub struct Attribute {
    pub iid: IID,
    pub type_: AttributeType,
    pub value: Value,
    pub is_inferred: bool,
}
Attribute is an instance of the attribute type and has a value. This value is fixed and unique for every given instance of the attribute type. Attributes can be uniquely addressed by their type and value.

Fields

iid: IID

The unique id of this Attribute

type_: AttributeType

The type which this Attribute belongs to

value: Value

The value which this Attribute instance holds.

is_inferred: bool

If this Attribute is inferred by a [Reasoning Rule] or not