#[repr(C)]pub struct Duration {
pub months: u32,
pub days: u32,
pub nanos: u64,
}Expand description
A relative duration, which contains months, days, and nanoseconds. Can be used for calendar-relative durations (eg 7 days forward), or for absolute durations using the nanosecond component When used as an absolute duration, convertible to chrono::Duration
Fields
months: u32Number of calendar months in the duration.
days: u32Number of calendar days in the duration.
nanos: u64Number of nanoseconds in the duration.
Implementations
Sourceimpl Duration
impl Duration
Sourcepub const NANOS_PER_SEC: u64 = 1_000_000_000
pub const NANOS_PER_SEC: u64 = 1_000_000_000
Number of nanoseconds in one second.
Sourcepub const DAYS_PER_WEEK: u32 = 7
pub const DAYS_PER_WEEK: u32 = 7
Number of days in one week.
Sourcepub const MONTHS_PER_YEAR: u32 = 12
pub const MONTHS_PER_YEAR: u32 = 12
Number of months in one year.
pub fn new(months: u32, days: u32, nanos: u64) -> Self