TypeDBDriver

Struct TypeDBDriver 

pub struct TypeDBDriver { /* private fields */ }
A connection to a TypeDB server which serves as the starting point for all interaction.

Implementations

Source

impl TypeDBDriver

pub const DEFAULT_ADDRESS: &'static str = "127.0.0.1:1729"

pub async fn new( addresses: Addresses, credentials: Credentials, driver_options: DriverOptions, ) -> Result<Self>

Creates a new TypeDB Server connection.

Arguments
  • addresses — The address(es) of the TypeDB Server(s), provided in a unified format
  • credentials — The Credentials to connect with
  • driver_options — The DriverOptions to connect with
Examples
TypeDBDriver::new(Addresses::try_from_address_str("127.0.0.1:1729").unwrap(), Credentials::new("username", "password"), DriverOptions::new(true, None)).await
pub async fn new_with_description( addresses: Addresses, credentials: Credentials, driver_options: DriverOptions, driver_lang: impl AsRef<str>, ) -> Result<Self>

Creates a new TypeDB Server connection with a description. This method is generally used by TypeDB drivers built on top of the Rust driver. In other cases, use Self::new instead.

Arguments
  • addresses — The address(es) of the TypeDB Server(s), provided in a unified format
  • credentials — The Credentials to connect with
  • driver_options — The DriverOptions to connect with
  • driver_lang — The language of the driver connecting to the server
Examples
TypeDBDriver::new_with_description(Addresses::try_from_address_str("127.0.0.1:1729").unwrap(), Credentials::new("username", "password"), DriverOptions::new(true, None), "rust").await
pub fn is_open(&self) -> bool

Checks it this connection is opened.

Examples
driver.is_open()
pub fn databases(&self) -> &DatabaseManager

The DatabaseManager for this connection, providing access to database management methods.

Examples
driver.databases()
pub fn users(&self) -> &UserManager

The UserManager for this connection, providing access to user management methods.

Examples
driver.databases()
pub async fn server_version(&self) -> Result<ServerVersion>

Retrieves the server’s version, using default automatic server routing.

See Self::server_version_with_routing for more details and options.

Examples
driver.server_version().await
pub async fn server_version_with_routing( &self, server_routing: ServerRouting, ) -> Result<ServerVersion>

Retrieves the server’s version.

Arguments
  • server_routing — The server routing directive to use for the operation
Examples
driver.server_version_with_routing(ServerRouting::Auto).await;
pub async fn servers(&self) -> Result<HashSet<Server>>

Retrieves the servers, using default automatic server routing.

See Self::servers_with_routing for more details and options.

Examples
driver.servers().await;
pub async fn servers_with_routing( &self, server_routing: ServerRouting, ) -> Result<HashSet<Server>>

Retrieves the servers.

Arguments
  • server_routing — The server routing directive to use for the operation
Examples
driver.servers_with_routing(ServerRouting::Auto).await;
pub async fn primary_server(&self) -> Result<Option<AvailableServer>>

Retrieves the primary server, if exists, using default automatic server routing.

See Self::primary_server_with_routing for more details and options.

Examples
driver.primary_server().await;
pub async fn primary_server_with_routing( &self, server_routing: ServerRouting, ) -> Result<Option<AvailableServer>>

Retrieves the primary server, if exists.

Arguments
  • server_routing — The server routing directive to use for the operation
Examples
driver.primary_server_with_routing(ServerRouting::Auto).await;
pub fn options(&self) -> &DriverOptions

Updates address translation of the driver. This lets you actualize new translation information without recreating the driver from scratch. Useful after registering new replicas requiring address translation. This operation will update existing connections using the provided addresses.

The DriverOptions for this connection.

Examples
driver.options()
pub fn configured_addresses(&self) -> &Addresses

The Addresses this connection is configured to.

Examples
driver.configured_addresses()
pub async fn transaction( &self, database_name: impl AsRef<str>, transaction_type: TransactionType, ) -> Result<Transaction>

Opens a transaction with default options.

See TypeDBDriver::transaction_with_options for more details.

Examples
driver.transaction(database_name, TransactionType::Read).await;
pub async fn transaction_with_options( &self, database_name: impl AsRef<str>, transaction_type: TransactionType, options: TransactionOptions, ) -> Result<Transaction>

Opens a new transaction with custom transaction options.

Arguments
  • database_name — The name of the database to connect to
  • transaction_type — The TransactionType to open the transaction with
  • options — The TransactionOptions to open the transaction with
Examples
transaction.transaction_with_options(database_name, transaction_type, options).await
pub fn force_close(&self) -> Result

Closes this connection if it is open.

Examples
driver.force_close()