pub enum Addresses {
Direct(Vec<Address>),
Translated(HashMap<Address, Address>),
}Expand description
A collection of server addresses used for connection.
Variants
Implementations
Sourceimpl Addresses
impl Addresses
Sourcepub fn try_from_address_str(address_str: impl AsRef<str>) -> Result<Self>
pub fn try_from_address_str(address_str: impl AsRef<str>) -> Result<Self>
Prepare addresses based on a single “host:port” string.
Examples
Addresses::try_from_address_str("127.0.0.1:11729")Sourcepub fn from_address(address: Address) -> Self
pub fn from_address(address: Address) -> Self
Prepare addresses based on a single TypeDB address.
Examples
let address = "127.0.0.1:11729".parse().unwrap();
Addresses::from_address(address)Sourcepub fn try_from_addresses_str(
addresses_str: impl IntoIterator<Item = impl AsRef<str>>,
) -> Result<Self>
pub fn try_from_addresses_str( addresses_str: impl IntoIterator<Item = impl AsRef<str>>, ) -> Result<Self>
Prepare addresses based on multiple “host:port” strings. Is used to specify multiple addresses connect to.
Examples
Addresses::try_from_addresses_str(["127.0.0.1:11729", "127.0.0.1:11730", "127.0.0.1:11731"])Sourcepub fn from_addresses(addresses: impl IntoIterator<Item = Address>) -> Self
pub fn from_addresses(addresses: impl IntoIterator<Item = Address>) -> Self
Prepare addresses based on multiple TypeDB addresses.
Examples
let address1 = "127.0.0.1:11729".parse().unwrap();
let address2 = "127.0.0.1:11730".parse().unwrap();
let address3 = "127.0.0.1:11731".parse().unwrap();
Addresses::from_addresses([address1, address2, address3])Sourcepub fn try_from_translation_str(
addresses_str: HashMap<impl AsRef<str>, impl AsRef<str>>,
) -> Result<Self>
pub fn try_from_translation_str( addresses_str: HashMap<impl AsRef<str>, impl AsRef<str>>, ) -> Result<Self>
Prepare addresses based on multiple key-value (public-private) “key:port” string pairs. Translation map from addresses to be used by the driver for connection to addresses received from the TypeDB server(s).
Examples
Addresses::try_from_addresses_str(
[
("typedb-cloud.ext:11729", "127.0.0.1:11729"),
("typedb-cloud.ext:11730", "127.0.0.1:11730"),
("typedb-cloud.ext:11731", "127.0.0.1:11731")
].into()
)Sourcepub fn from_translation(addresses: HashMap<Address, Address>) -> Self
pub fn from_translation(addresses: HashMap<Address, Address>) -> Self
Prepare addresses based on multiple key-value (public-private) TypeDB address pairs. Translation map from addresses to be used by the driver for connection to addresses received from the TypeDB server(s).
Examples
let translation: HashMap<Address, Address> = [
("typedb-cloud.ext:11729".parse()?, "127.0.0.1:11729".parse()?),
("typedb-cloud.ext:11730".parse()?, "127.0.0.1:11730".parse()?),
("typedb-cloud.ext:11731".parse()?, "127.0.0.1:11731".parse()?)
].into();
Addresses::from_translation(translation)Trait Implementations
impl Eq for Addresses
impl StructuralPartialEq for Addresses