pub enum ServerRouting {
Auto,
Direct {
address: Address,
},
}Expand description
Server routing directive for operations against a distributed server. All driver methods have default recommended values, however, some operations can be configured in order to target a specific server in the cluster. This setting does not affect clusters with a single node.
Variants
Auto
Automatic server routing. Driver automatically selects the server (primary in clusters).
Direct
Route to a specific known server at the given address. Mostly used for debugging purposes.