Module given

Module given 

Structs

GivenRow
Helper for building a single row to add to a GivenRows instance.
GivenRows
Rows of data to be used as input to a TypeQL query using a given stage.
GivenRowsHeader

Enums

GivenRowEntry