pub struct Transaction<'a> { /* private fields */ }Expand description
A transaction with a TypeDB database.
Implementations
Sourceimpl Transaction<'_>
impl Transaction<'_>
Sourcepub fn type_(&self) -> TransactionType
pub fn type_(&self) -> TransactionType
Retrieves the transaction’s type (READ or WRITE).
Sourcepub fn query(&self) -> QueryManager<'_>
pub fn query(&self) -> QueryManager<'_>
Retrieves theQueryManager for this Transaction, from which any TypeQL query can be executed.
Sourcepub fn concept(&self) -> ConceptManager<'_>
pub fn concept(&self) -> ConceptManager<'_>
The ConceptManager for this transaction, providing access to all Concept API methods.
Sourcepub fn logic(&self) -> LogicManager<'_>
pub fn logic(&self) -> LogicManager<'_>
Retrieves the LogicManager for this Transaction, providing access to all Concept API - Logic methods.
Sourcepub fn force_close(&self)
pub fn force_close(&self)